@@ -1,5 +1,5 @@
 /*	HomeBank -- Free, easy, personal accounting for everyone.
- *	Copyright (C) 1995-2021 Maxime DOYEN
+ *	Copyright (C) 1995-2022 Maxime DOYEN
  *
  *	This file is part of HomeBank.
  *
@@ -553,7 +553,7 @@ struct register_panel_data *data;
 gchar *name, *filepath;
 GString *node;
 GIOChannel *io;
-gboolean detailsplit;
+gboolean hassplit, hasstatus;
 
 	DB( g_print("\n[register] export csv\n") );
 
@@ -563,15 +563,18 @@ gboolean detailsplit;
 
 	filepath = g_build_filename(PREFS->path_export, name, NULL);
 
-	if( ui_dialog_export_csv(GTK_WINDOW(data->window), &filepath, &detailsplit, data->showall) == GTK_RESPONSE_ACCEPT )
+	if( ui_dialog_export_csv(GTK_WINDOW(data->window), &filepath, &hassplit, &hasstatus, data->showall) == GTK_RESPONSE_ACCEPT )
 	{
-		DB( g_printf(" filename is'%s'\n", filepath) );
+		DB( g_printf(" filename is '%s'\n", filepath) );
+		DB( g_printf(" detail split %d\n", detailsplit) );
+		DB( g_printf(" status column '%d'\n", statcol) );
+
 		io = g_io_channel_new_file(filepath, "w", NULL);
 		if(io != NULL)
 		{
-			//TODO: add showall et detailsplit here
+			//TODO: add showall & detailsplit here
 			//+ handle it
-			node = list_txn_to_string(GTK_TREE_VIEW(data->LV_ope), FALSE, detailsplit, data->showall);
+			node = list_txn_to_string(GTK_TREE_VIEW(data->LV_ope), FALSE, hassplit, hasstatus, data->showall);
 
 			g_io_channel_write_chars(io, node->str, -1, NULL, NULL);
 			g_io_channel_unref (io);
@@ -849,6 +852,25 @@ struct register_panel_data *data;
 }
 
 
+static gboolean register_panel_cb_recon_change (GtkWidget *widget, gboolean state, gpointer user_data)
+{
+struct register_panel_data *data;
+
+	DB( g_print("\n[register] cb recon change\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+	
+	DB( g_print("\n[register] changes is %d\n", state) );
+	
+	gtk_image_set_from_icon_name(GTK_IMAGE(data->IM_reconchange), state == TRUE ? ICONNAME_CHANGES_ALLOW : ICONNAME_CHANGES_PREVENT, GTK_ICON_SIZE_BUTTON);
+
+	register_panel_update(data->LV_ope, GINT_TO_POINTER(FLG_REG_SENSITIVE));
+
+	return FALSE;
+}
+
+
+
 static void register_panel_cb_filter_daterange(GtkWidget *widget, gpointer user_data)
 {
 struct register_panel_data *data;
@@ -1046,7 +1068,7 @@ gushort lpos = 1;
 
 	if( minbalope != NULL )
 		minbalope->dspflags |= TXN_DSPFLG_LOWBAL;
-	
+
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_ope));
 	list_txn_sort_force(GTK_TREE_SORTABLE(model), NULL);
 	
@@ -1538,8 +1560,15 @@ gboolean result;
 					//manage current window display stuff
 					
 					//#1270687: sort if date changed
-					if(old_txn->date != new_txn->date)
-						data->do_sort = TRUE;
+					//if(old_txn->date != new_txn->date)
+					//	data->do_sort = TRUE;
+					//#1931816: sort is already done in deftransaction_external_edit
+					// but still to be done if showall
+					if(data->showall == FALSE)
+					{
+					GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_ope));
+						list_txn_sort_force(GTK_TREE_SORTABLE(model), NULL);
+					}
 
 					// txn changed of account
 					//TODO: maybe this should move to deftransaction_external_edit
@@ -1894,7 +1923,7 @@ gint count = 0;
 	/* update disabled things */
 	if(flags & FLG_REG_SENSITIVE)
 	{
-	gboolean sensitive, psensitive, nsensitive;
+	gboolean reconchange, sensitive, psensitive, nsensitive;
 	GtkTreeModel *model;
 	gint sort_column_id;
 	GtkSortType order;
@@ -1906,6 +1935,8 @@ gint count = 0;
 		count = gtk_tree_selection_count_selected_rows(selection);
 		DB( g_print(" - count = %d\n", count) );
 
+		ope = list_txn_get_active_transaction(GTK_TREE_VIEW(data->LV_ope));
+
 		//showall part
 		visible = !data->showall;
 		hb_widget_visible(data->MI_exportpdf, visible);
@@ -1919,6 +1950,16 @@ gint count = 0;
 		//#1873248 Auto. assignments faulty visible on 'All transactions' window
 		hb_widget_visible(data->MI_autoassign, visible);
 		
+		//1909749 lock/unlock reconciled
+		reconchange = FALSE;
+		if( ope != NULL )
+		{
+			if( (ope->status != TXN_STATUS_RECONCILED) || (gtk_switch_get_active (GTK_SWITCH(data->SW_reconchange)) == TRUE) )
+				reconchange = TRUE;
+
+			DB( g_print(" - reconchange = %d (%d %d)\n", reconchange, ope->status != TXN_STATUS_RECONCILED, gtk_switch_get_state (GTK_SWITCH(data->SW_reconchange)) ) );
+		}
+
 		//5.3.1 if closed account : disable any change
 		sensitive =  TRUE;
 		if( (data->showall == FALSE) && (data->acc->flags & AF_CLOSED) )
@@ -1934,36 +1975,38 @@ gint count = 0;
 		sensitive = (count != 1 ) ? FALSE : TRUE;
 		gtk_widget_set_sensitive(data->MI_herit, sensitive);
 		gtk_widget_set_sensitive(data->MI_popherit, sensitive);
-		gtk_widget_set_sensitive(data->MI_edit, sensitive);
-		gtk_widget_set_sensitive(data->MI_popedit, sensitive);
+		gtk_widget_set_sensitive(data->MI_edit, reconchange ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->MI_popedit, reconchange ? sensitive : FALSE);
 		gtk_widget_set_sensitive(data->BT_herit, sensitive);
-		gtk_widget_set_sensitive(data->BT_edit, sensitive);
+		gtk_widget_set_sensitive(data->BT_edit, reconchange ? sensitive : FALSE);
 
 		//txn have split
-		ope = list_txn_get_active_transaction(GTK_TREE_VIEW(data->LV_ope));
 		sensitive = (count == 1) && (ope != NULL) && (ope->flags & OF_SPLIT) ? TRUE : FALSE;
 		gtk_widget_set_sensitive(data->MI_popviewsplit, sensitive);
 		
 		// single: disable multiedit
 		sensitive = (count <= 1 ) ? FALSE : TRUE;
-		gtk_widget_set_sensitive(data->MI_multiedit, sensitive);
+		//1909749 lock/unlock reconciled
+		if( (txn_list_get_count_reconciled(GTK_TREE_VIEW(data->LV_ope)) > 0) && (gtk_switch_get_active (GTK_SWITCH(data->SW_reconchange)) == FALSE) )
+			sensitive = FALSE;
+		gtk_widget_set_sensitive(data->MI_multiedit   , sensitive);
 		gtk_widget_set_sensitive(data->MI_popmultiedit, sensitive);
-		gtk_widget_set_sensitive(data->BT_multiedit, sensitive);
+		gtk_widget_set_sensitive(data->BT_multiedit   , sensitive);
 
 		// no selection: disable reconcile, delete
 		sensitive = (count > 0 ) ? TRUE : FALSE;
 		gtk_widget_set_sensitive(data->MI_copy, sensitive);
-		gtk_widget_set_sensitive(data->ME_menustatus, sensitive);
-		gtk_widget_set_sensitive(data->ME_popmenustatus, sensitive);
-		gtk_widget_set_sensitive(data->MI_delete, sensitive);
-		gtk_widget_set_sensitive(data->MI_popdelete, sensitive);
+		gtk_widget_set_sensitive(data->ME_menustatus, reconchange ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->ME_popmenustatus, reconchange ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->MI_delete, reconchange ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->MI_popdelete, reconchange ? sensitive : FALSE);
 		gtk_widget_set_sensitive(data->MI_assign, sensitive);
 		gtk_widget_set_sensitive(data->MI_popassign, sensitive);
 		gtk_widget_set_sensitive(data->MI_template, sensitive);
 		gtk_widget_set_sensitive(data->MI_poptemplate, sensitive);
-		gtk_widget_set_sensitive(data->BT_delete ,sensitive);
-		gtk_widget_set_sensitive(data->BT_clear, sensitive);
-		gtk_widget_set_sensitive(data->BT_reconcile, sensitive);
+		gtk_widget_set_sensitive(data->BT_delete, reconchange ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->BT_clear, reconchange ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->BT_reconcile, reconchange ? sensitive : FALSE);
 		gtk_widget_set_sensitive(data->BT_template, sensitive);
 
 		//edit menu
@@ -2113,6 +2156,7 @@ GtkTreeModel *model;
 GtkTreeIter iter;
 gint col_id, count;
 Transaction *ope;
+gboolean reconchange;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(treeview), GTK_TYPE_WINDOW)), "inst_data");
 
@@ -2120,23 +2164,27 @@ Transaction *ope;
 	if( (data->showall == FALSE) && (data->acc->flags & AF_CLOSED) )
 		return;
 
-
 	col_id = gtk_tree_view_column_get_sort_column_id (col);
-
-	count = gtk_tree_selection_count_selected_rows(gtk_tree_view_get_selection(treeview));
-
-	model = gtk_tree_view_get_model(treeview);
+	count  = gtk_tree_selection_count_selected_rows(gtk_tree_view_get_selection(treeview));
+	model  = gtk_tree_view_get_model(treeview);
 
 	//get transaction double clicked to initiate the widget
 	gtk_tree_model_get_iter(model, &iter, path);
 	gtk_tree_model_get(model, &iter, MODEL_TXN_POINTER, &ope, -1);
 
-
 	DB( g_print ("%d rows been double-clicked on column=%d! ope=%s\n", count, col_id, ope->memo) );
 
 	if( count == 1)
 	{
-		register_panel_action(GTK_WIDGET(treeview), GINT_TO_POINTER(ACTION_ACCOUNT_EDIT));
+		//1909749 lock/unlock reconciled	
+		reconchange = FALSE;
+		if( (ope->status != TXN_STATUS_RECONCILED) || (gtk_switch_get_active (GTK_SWITCH(data->SW_reconchange)) == TRUE) )
+			reconchange = TRUE;
+
+		if( reconchange == TRUE )
+		{
+			register_panel_action(GTK_WIDGET(treeview), GINT_TO_POINTER(ACTION_ACCOUNT_EDIT));
+		}
 	}
 	else
 	{
@@ -2542,8 +2590,9 @@ GtkWidget *register_panel_window_new(Account *acc)
 {
 struct register_panel_data *data;
 struct WinGeometry *wg;
-GtkWidget *window, *mainbox, *intbox, *menubar, *table, *sw, *bar;
+GtkWidget *window, *mainbox, *intbox, *menubar, *table, *sw, *bar, *hbox;
 GtkWidget *treeview, *label, *widget, *image;
+gint row;
 
 	DB( g_print("\n[register] create_register_panel_window\n") );
 
@@ -2638,62 +2687,73 @@ GtkWidget *treeview, *label, *widget, *image;
 	gtk_widget_set_margin_bottom(table, SPACING_SMALL);
 	gtk_box_pack_start (GTK_BOX (intbox), table, FALSE, FALSE, 0);
 
-	label = make_label_widget(_("_Range:"));
-	gtk_grid_attach (GTK_GRID(table), label, 0, 0, 1, 1);
-	data->CY_range = make_daterange(label, DATE_RANGE_CUSTOM_SHOW);
-	gtk_grid_attach (GTK_GRID(table), data->CY_range, 1, 0, 1, 1);
+	row = 0;
+	//#1909749 lock/unlock reconciled
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+	gtk_grid_attach (GTK_GRID(table), hbox, row, 0, 1, 1);
+	
+	widget = gtk_image_new_from_icon_name (ICONNAME_CHANGES_PREVENT, GTK_ICON_SIZE_BUTTON);
+	data->IM_reconchange = widget;
+	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 
+	widget = gtk_switch_new();
+	data->SW_reconchange = widget;
+	gtk_widget_set_valign (widget, GTK_ALIGN_CENTER);
+	gtk_widget_set_tooltip_text (widget, _("Lock/unlock reconciled transaction"));
+	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
+
+	row++;
+	label = make_label_widget(_("_Range:"));
+	gtk_grid_attach (GTK_GRID(table), label, row, 0, 1, 1);
+	row++;
+	data->CY_range = make_daterange(label, DATE_RANGE_CUSTOM_SHOW);
+	gtk_grid_attach (GTK_GRID(table), data->CY_range, row, 0, 1, 1);
+
+	row++;
 	widget = gtk_toggle_button_new();
 	image = gtk_image_new_from_icon_name (ICONNAME_HB_OPE_FUTURE, GTK_ICON_SIZE_MENU);
 	g_object_set (widget, "image", image,  NULL);
 	gtk_widget_set_tooltip_text (widget, _("Toggle show future transaction"));
 	data->CM_future = widget;
-	gtk_grid_attach (GTK_GRID(table), widget, 2, 0, 1, 1);
+	gtk_grid_attach (GTK_GRID(table), widget, row, 0, 1, 1);
 
+	row++;
 	label = make_label_widget(_("_Type:"));
-	gtk_grid_attach (GTK_GRID(table), label, 3, 0, 1, 1);
+	gtk_grid_attach (GTK_GRID(table), label, row, 0, 1, 1);
+	row++;
 	data->CY_type = make_cycle(label, CYA_FLT_TYPE);
-	gtk_grid_attach (GTK_GRID(table), data->CY_type, 4, 0, 1, 1);
+	gtk_grid_attach (GTK_GRID(table), data->CY_type, row, 0, 1, 1);
 
+	row++;
 	label = make_label_widget(_("_Status:"));
-	gtk_grid_attach (GTK_GRID(table), label, 5, 0, 1, 1);
+	gtk_grid_attach (GTK_GRID(table), label, row, 0, 1, 1);
+	row++;
 	data->CY_status = make_cycle(label, CYA_FLT_STATUS);
-	gtk_grid_attach (GTK_GRID(table), data->CY_status, 6, 0, 1, 1);
+	gtk_grid_attach (GTK_GRID(table), data->CY_status, row, 0, 1, 1);
 
+	row++;
 	//widget = gtk_button_new_with_mnemonic (_("Reset _filters"));
 	widget = gtk_button_new_with_mnemonic (_("_Reset"));
 	data->BT_reset = widget;
-	gtk_grid_attach (GTK_GRID(table), widget, 7, 0, 1, 1);
+	gtk_grid_attach (GTK_GRID(table), widget, row, 0, 1, 1);
 
+	row++;
 	widget = make_image_button(ICONNAME_HB_FILTER, _("Open the list filter"));
 	data->BT_filter = widget;
-	gtk_grid_attach (GTK_GRID(table), widget, 8, 0, 1, 1);
-	
-	
+	gtk_grid_attach (GTK_GRID(table), widget, row, 0, 1, 1);
 	
+	row++;
 	//TRANSLATORS: this is for Euro specific users, a toggle to display in 'Minor' currency
 	widget = gtk_check_button_new_with_mnemonic (_("Euro _minor"));
 	data->CM_minor = widget;
-	gtk_grid_attach (GTK_GRID(table), widget, 9, 0, 1, 1);
+	gtk_grid_attach (GTK_GRID(table), widget, row, 0, 1, 1);
 
 	// account name (+ balance)
-	/*
-	widget = gtk_image_new_from_icon_name (ICONNAME_CHANGES_PREVENT, GTK_ICON_SIZE_BUTTON);
-	data->IM_closed = widget;
-	gtk_grid_attach (GTK_GRID(table), widget, 6, 0, 1, 1);
-
-	label = gtk_label_new(NULL);
-	data->LB_name = label;
-	gimp_label_set_attributes (GTK_LABEL (label), PANGO_ATTR_SCALE, PANGO_SCALE_LARGE, -1);
-	gtk_widget_set_halign (label, GTK_ALIGN_START);
-	gtk_widget_set_hexpand (label, TRUE);
-	gtk_grid_attach (GTK_GRID(table), label, 7, 0, 1, 1);
-	*/
-
+	row++;
 	//space
 	label = gtk_label_new(NULL);
 	gtk_widget_set_hexpand (label, TRUE);
-	gtk_grid_attach (GTK_GRID(table), label, 10, 0, 1, 1);
+	gtk_grid_attach (GTK_GRID(table), label, row, 0, 1, 1);
 
 	
 	//test menubutton
@@ -2701,16 +2761,17 @@ GtkWidget *treeview, *label, *widget, *image;
 	widget = gtk_menu_button_new();
 	image = gtk_image_new_from_icon_name (ICONNAME_HB_BUTTON_MENU, GTK_ICON_SIZE_MENU);
 	g_object_set (widget, "image", image,  NULL);	
-	gtk_grid_attach (GTK_GRID(table), widget, 9, 0, 1, 1);
+	gtk_grid_attach (GTK_GRID(table), widget, row, 0, 1, 1);
 	*/
 
-
+	row++;
 	//quick search
 	widget = make_search ();
 	data->ST_search = widget;
 	gtk_widget_set_size_request(widget, HB_MINWIDTH_SEARCH, -1);
 	gtk_widget_set_halign(widget, GTK_ALIGN_END);
-	gtk_grid_attach (GTK_GRID(table), widget, 11, 0, 1, 1);
+	gtk_grid_attach (GTK_GRID(table), widget, row, 0, 1, 1);
+
 
 	/* test */
 	table = gtk_grid_new();
@@ -2730,6 +2791,8 @@ GtkWidget *treeview, *label, *widget, *image;
 
 	// text total/selection
 	label = make_label(NULL, 0.0, 0.5);
+	//#1930395 text selectable for copy/paste 
+	gtk_label_set_selectable(GTK_LABEL(label), TRUE);
 	//gtk_widget_set_halign (label, GTK_ALIGN_START);
 	gtk_widget_set_halign (label, GTK_ALIGN_CENTER);
 	gtk_widget_set_hexpand (label, TRUE);
@@ -2738,7 +2801,7 @@ GtkWidget *treeview, *label, *widget, *image;
 	gtk_grid_attach (GTK_GRID(table), label, 1, 0, 1, 1);
 
 
-	// lock + account name
+	// account name
 
 	label = gtk_label_new(_("Reconciled:"));
 	//data->LB_recon = label;
@@ -2846,6 +2909,8 @@ GtkWidget *treeview, *label, *widget, *image;
 	g_signal_connect (data->MI_filter    , "activate", G_CALLBACK (register_panel_action_editfilter), (gpointer)data);
 	g_signal_connect (data->MI_conveuro  , "activate", G_CALLBACK (register_panel_action_converttoeuro), (gpointer)data);
 
+	g_signal_connect (data->SW_reconchange, "state-set", G_CALLBACK (register_panel_cb_recon_change), NULL);
+
 	data->handler_id[HID_RANGE]	 = g_signal_connect (data->CY_range , "changed", G_CALLBACK (register_panel_cb_filter_daterange), NULL);
 	data->handler_id[HID_TYPE]	 = g_signal_connect (data->CY_type	, "changed", G_CALLBACK (register_panel_cb_filter_type), NULL);
 	data->handler_id[HID_STATUS] = g_signal_connect (data->CY_status, "changed", G_CALLBACK (register_panel_cb_filter_status), NULL);
@@ -2897,6 +2962,7 @@ GtkWidget *treeview, *label, *widget, *image;
 		gtk_window_maximize(GTK_WINDOW(window));
 	
 	gtk_widget_show_all (window);
+	
 	gtk_widget_hide(data->IB_duplicate);
 	
 	/* make sure splash is up */
