@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -188,7 +188,7 @@ gchar *version;
   };
 */
 
-	static const gchar *copyright = "Copyright \xc2\xa9 1995-2021 - Maxime DOYEN";
+	static const gchar *copyright = "Copyright \xc2\xa9 1995-2022 - Maxime DOYEN";
 
 
 
@@ -431,7 +431,7 @@ static void ui_mainwindow_action_deftag(void)
 
 	ui_tag_manage_dialog();
 
-	//ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
 }
 
 
@@ -1114,6 +1114,10 @@ gint r;
 
 			homebank_lastopenedfiles_save();
 
+			//#1931816 should always sort all txn once
+			DB( g_print(" - sort txn all account\n") );
+			account_transaction_sort();
+
 			//TODO: delete this after computing done at xml read
 			account_compute_balances();
 
@@ -1913,7 +1917,7 @@ GtkWidget *toolbar, *button, *menu;
 
 	toolbar = gtk_toolbar_new();
 	
-	data->BT_new  = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_FILE_NEW, N_("New"), _("Create a new file"));
+	data->BT_new  = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_FILE_NEW, _("New"), _("Create a new file"));
 	data->BT_open = button = gtk_widget_new(GTK_TYPE_MENU_TOOL_BUTTON,
 		"icon-name", ICONNAME_HB_FILE_OPEN,
 		"label", _("Open"),
@@ -1924,7 +1928,7 @@ GtkWidget *toolbar, *button, *menu;
 	gtk_menu_tool_button_set_menu (GTK_MENU_TOOL_BUTTON (button), menu);
 	gtk_menu_tool_button_set_arrow_tooltip_text (GTK_MENU_TOOL_BUTTON (button), _("Open a recently used file"));
 	
-	data->BT_save = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_FILE_SAVE, N_("Save"), _("Save the current file"));
+	data->BT_save = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_FILE_SAVE, _("Save"), _("Save the current file"));
 
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), gtk_separator_tool_item_new(), -1);
 
