@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -43,23 +43,116 @@ char *chart_colors[] =
 	"Office 2013",
 	"Analytics",
 	"YNAB",
+	"Quicken 2017",
+	"Mint",
+	"Material",
+	"Nord",
 	NULL
 };
 
 
+struct rgbcol nord_colors[] =
+{
+	{ 191,  97, 106 },
+	{ 235, 203, 139 },
+	{ 163, 190, 140 },
+	{  94, 129, 172 },
+	{ 180, 142, 173 },
+	{ 193, 158, 102 },	/* added*/
+	{ 208, 135, 112 },
+	{ 129, 161, 193 },
+	{ 238, 187, 119 },	/* added */
+	{ 143, 188, 187 },
+	{ 150, 150, 150 }	//grey/other
+};
+int nord_nbcolors = G_N_ELEMENTS(nord_colors);
+
+
+struct rgbcol material_colors[] =
+{
+	{ 244,  67,  54 },
+	{  63,  81, 181 },
+	{   0, 150, 136 },
+	{ 255, 235,  59 },
+	{ 233,  30,  99 },
+	{  33, 150, 243 },
+	{  76, 175,  80 },
+	{ 255, 193,   7 },
+	{ 156,  39, 176 },
+	{   3, 169, 244 },
+	{ 139, 195,  74 },
+	{ 255, 152,   0 },
+	{ 103,  58, 183 },
+	{   0, 188, 212 },
+	{ 205, 220,  57 },
+	{ 255,  87,  34 },
+
+	//{ 121, 85, 72 },
+	//{ 158, 158, 158 },
+	//{ 96, 125, 139 },
+
+};
+int material_nbcolors = G_N_ELEMENTS(material_colors);
+
+
+struct rgbcol mint_colors[] =
+{
+	{ 255, 207,  64 },
+	{ 255, 171,  64 },
+	{  69, 202, 230 },
+	{  22, 126, 230 },
+	{ 241, 132, 212 },
+	{ 242,  72,  72 },
+	{ 166, 237,  94 },
+	{  10, 198, 117 },
+	{  24, 158, 124 },
+	{ 188, 146, 251 },
+	{ 122,  71, 215 },
+	{ 255, 255, 139 },
+	{ 159, 159, 159 }	//grey/other
+
+};
+int mint_nbcolors = G_N_ELEMENTS(mint_colors);
+
+
+struct rgbcol quicken2017_colors[] =
+{
+	{  64, 191, 117 },
+	{ 119, 131, 255 },
+	{ 214, 137, 251 },
+	{ 255, 156,  78 },
+	{  28, 168, 221 },
+	{ 255, 116, 162 },
+	{  78, 223, 225 },
+	{  85, 120, 195 },
+	{ 182, 198,  71 },
+	{ 255,  85, 108 },
+	{ 113, 113, 113 }	//grey/other
+
+};
+int quicken2017_nbcolors = G_N_ELEMENTS(quicken2017_colors);
+
+
+
 struct rgbcol ynab_colors[] =
 {
-	{ 238, 118,  96 },
-	{ 245, 189, 115 },
-	{ 239, 234, 172 },
-	{ 143, 186, 209 },
-	{ 211, 229, 134 },
-	{ 163, 180, 120 },
-	{ 167, 209, 195 },
-	{  51, 177, 191 },
-	{ 214, 227,  99 },
-	//{ 246, 166, 209 },	  // added color
-	{ 131, 131, 131 }	  // others
+	{ 234,  84,  57 },
+	{ 243, 173,  81 },
+	{ 235, 229, 152 },
+	{ 116, 169, 230 },
+	{ 225, 248, 129 },
+	{ 139, 161,  87 },
+	{ 145, 197, 180 },
+	{   0, 157, 174 },
+	{ 203, 219,  60 },
+	{ 228, 211,  84 },
+	{ 128, 133, 233 },
+	{ 247, 163,  92 },
+	{ 164, 192, 208 },
+	{ 124, 181, 236 },
+	{ 199, 246, 190 },
+
+	{ 105, 106, 105 }	  //grey/other
 };
 int ynab_nbcolors = G_N_ELEMENTS(ynab_colors);
 
@@ -92,6 +185,8 @@ struct rgbcol money_colors[] =
 	{ 221, 216, 115 },
 	{  77, 103, 137 },
 	{ 165, 181, 156 }
+	
+	//grey/other
 };
 int money_nbcolors = G_N_ELEMENTS(money_colors);
 
@@ -109,7 +204,7 @@ struct rgbcol quicken_colors[] =
 
 	{  70, 161, 100 },
 	{ 220, 106,   0 },
-	{ 113, 113, 113 }	  // others
+	{ 113, 113, 113 }	  //grey/other
 };
 int quicken_nbcolors = G_N_ELEMENTS(quicken_colors);
 
@@ -127,7 +222,7 @@ struct rgbcol analytics_colors[] =
 
 	{ 106, 249, 196 },
 	{ 178, 222, 255 },
-	{ 204, 204, 204 }	  // others
+	{ 204, 204, 204 }	  //grey/other
 };
 int analytics_nbcolors = G_N_ELEMENTS(analytics_colors);
 
@@ -154,6 +249,7 @@ struct rgbcol office2010_colors[] =
 	{ 156, 137, 182 },
 	{ 123, 185, 206 },
 	{ 248, 170, 121 }
+	//grey/other
 };
 int office2010_nbcolors = G_N_ELEMENTS(office2010_colors);
 
@@ -180,6 +276,7 @@ struct rgbcol office2013_colors[] =
 	{ 255, 205,  51  },
 	{ 105, 142, 208  },
 	{ 140, 193, 104  }
+	//grey/other
 };
 int office2013_nbcolors = G_N_ELEMENTS(office2013_colors);
 
@@ -415,6 +512,38 @@ void colorscheme_init(GtkColorScheme *scheme, gint index)
 			scheme->cs_red = 0;
 			scheme->cs_orange = 1;
 			break;
+		case CHART_COLMAP_QUICKEN2017:
+			scheme->colors = quicken2017_colors;
+			scheme->nb_cols = quicken2017_nbcolors;
+			scheme->cs_blue = 7;
+			scheme->cs_green = 0;
+			scheme->cs_red = 9;
+			scheme->cs_orange = 3;
+			break;
+		case CHART_COLMAP_MINT:
+			scheme->colors = mint_colors;
+			scheme->nb_cols = mint_nbcolors;
+			scheme->cs_blue = 3;
+			scheme->cs_green = 7;
+			scheme->cs_red = 5;
+			scheme->cs_orange = 1;
+			break;
+		case CHART_COLMAP_MATERIAL:
+			scheme->colors = material_colors;
+			scheme->nb_cols = material_nbcolors;
+			scheme->cs_blue = 5;
+			scheme->cs_green = 6;
+			scheme->cs_red = 0;
+			scheme->cs_orange = 7;
+			break;
+		case CHART_COLMAP_NORD:
+			scheme->colors = nord_colors;
+			scheme->nb_cols = nord_nbcolors;
+			scheme->cs_blue = 3;
+			scheme->cs_green = 2;
+			scheme->cs_red = 0;
+			scheme->cs_orange = 6;
+			break;
 	}
 
 
