@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -91,6 +91,10 @@ enum
 
 	CHART_TYPE_PIE,
 	CHART_TYPE_LINE,
+
+	CHART_TYPE_STACK,
+	CHART_TYPE_STACK100,
+
 	CHART_TYPE_MAX
 };
 
@@ -189,6 +193,12 @@ struct _GtkChart
 	double		rawmin, rawmax;
 	gdouble		total;
 
+	//TODO: test of total, in waiting something else
+	GtkTreeModel	*model;
+	gdouble		*colsum;
+	gchar       **collabel;
+	gint		nb_cols;
+
 	gchar		*title;
 	gchar		*subtitle;
 
@@ -218,19 +228,15 @@ struct _GtkChart
 
 	//dynamics
 	gint		hover, lasthover;
+	gint		colhover, lastcolhover;
 
 	struct _HbtkDrawContext context;
 	PangoFontDescription *pfd;
-//	gint				pfd_size;
 
 	gchar		buffer1[CHART_BUFFER_LENGTH];
 	gchar		buffer2[CHART_BUFFER_LENGTH];
 
 
-	//beta: pienew
-//	gint		leg_nb_l, leg_width_l, leg_vspace_l;
-//	gint		leg_nb_r, leg_width_r, leg_vspace_r;
-
 };
 
 
@@ -262,6 +268,10 @@ void gtk_chart_print(GtkChart *chart, GtkWindow *parent, gchar *dirname, gchar *
 /* public function */
 GtkWidget *gtk_chart_new(gint type);
 
+//TODO: temp
+void chart_data_series(GtkChart *chart, GtkTreeView *treeview, gint nbrows, gint nbcols);
+
+
 void gtk_chart_set_type(GtkChart *chart, gint type);
 void gtk_chart_set_color_scheme(GtkChart * chart, gint colorscheme);
 
