@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -367,6 +367,27 @@ Account *acc = da_acc_get(key);
 }
 
 
+void
+account_transaction_sort(void)
+{
+GList *lst_acc, *lnk_acc;
+
+	DB( g_print("\n[account] transaction sort\n") );
+
+	lst_acc = g_hash_table_get_values(GLOBALS->h_acc);
+	lnk_acc = g_list_first(lst_acc);
+	while (lnk_acc != NULL)
+	{
+	Account *acc = lnk_acc->data;
+	
+		da_transaction_queue_sort(acc->txn_queue);
+		lnk_acc = g_list_next(lnk_acc);
+	}
+
+	g_list_free(lst_acc);
+}
+
+
 /**
  * account_is_used:
  *
@@ -383,6 +404,8 @@ GList *lst_acc, *lnk_acc;
 GList *lnk_txn;
 gboolean retval;
 
+	DB( g_print("\n[account] is used\n") );
+
 	retval = FALSE;
 	lst_acc = NULL;
 
@@ -463,6 +486,8 @@ Account *existitem;
 gchar *stripname;
 gboolean retval = FALSE;
 
+	DB( g_print("\n[account] rename\n") );
+
 	stripname = g_strdup(newname);
 	g_strstrip(stripname);
 
@@ -549,40 +574,40 @@ guint32 maxkey, i;
 /**
  * private function to sub transaction amount from account balances
  */
-static void account_balances_sub_internal(Account *acc, Transaction *trn)
+static void account_balances_sub_internal(Account *acc, Transaction *txn)
 {
-	acc->bal_future -= trn->amount;
+	acc->bal_future -= txn->amount;
 
-	if(trn->date <= GLOBALS->today)
-		acc->bal_today -= trn->amount;
+	if(txn->date <= GLOBALS->today)
+		acc->bal_today -= txn->amount;
 
-	if(trn->status == TXN_STATUS_CLEARED)
-		acc->bal_clear -= trn->amount;
+	if(txn->status == TXN_STATUS_CLEARED)
+		acc->bal_clear -= txn->amount;
 
-	if(trn->status == TXN_STATUS_RECONCILED)
+	if(txn->status == TXN_STATUS_RECONCILED)
 	{
-		acc->bal_recon -= trn->amount;
-		acc->bal_clear -= trn->amount;
+		acc->bal_recon -= txn->amount;
+		acc->bal_clear -= txn->amount;
 	}
 }
 
 /**
  * private function to add transaction amount from account balances
  */
-static void account_balances_add_internal(Account *acc, Transaction *trn)
+static void account_balances_add_internal(Account *acc, Transaction *txn)
 {
-	acc->bal_future += trn->amount;
+	acc->bal_future += txn->amount;
 
-	if(trn->date <= GLOBALS->today)
-		acc->bal_today += trn->amount;
+	if(txn->date <= GLOBALS->today)
+		acc->bal_today += txn->amount;
 
-	if(trn->status == TXN_STATUS_CLEARED)
-		acc->bal_clear += trn->amount;
+	if(txn->status == TXN_STATUS_CLEARED)
+		acc->bal_clear += txn->amount;
 
-	if(trn->status == TXN_STATUS_RECONCILED)
+	if(txn->status == TXN_STATUS_RECONCILED)
 	{
-		acc->bal_recon += trn->amount;
-		acc->bal_clear += trn->amount;
+		acc->bal_recon += txn->amount;
+		acc->bal_clear += txn->amount;
 	}
 }
 
@@ -590,15 +615,15 @@ static void account_balances_add_internal(Account *acc, Transaction *trn)
 /**
  * public function to sub transaction amount from account balances
  */
-gboolean account_balances_sub(Transaction *trn)
+gboolean account_balances_sub(Transaction *txn)
 {
 
-	if( transaction_is_balanceable(trn) )
-	//if(!(trn->flags & OF_REMIND))
+	if( transaction_is_balanceable(txn) )
+	//if(!(txn->flags & OF_REMIND))
 	{
-		Account *acc = da_acc_get(trn->kacc);
+		Account *acc = da_acc_get(txn->kacc);
 		if(acc == NULL) return FALSE;
-		account_balances_sub_internal(acc, trn);
+		account_balances_sub_internal(acc, txn);
 		return TRUE;
 	}
 	return FALSE;
@@ -608,14 +633,14 @@ gboolean account_balances_sub(Transaction *trn)
 /**
  * public function to add transaction amount from account balances
  */
-gboolean account_balances_add(Transaction *trn)
+gboolean account_balances_add(Transaction *txn)
 {
-	if( transaction_is_balanceable(trn) )
-	//if(!(trn->flags & OF_REMIND))
+	if( transaction_is_balanceable(txn) )
+	//if(!(txn->flags & OF_REMIND))
 	{
-		Account *acc = da_acc_get(trn->kacc);
+		Account *acc = da_acc_get(txn->kacc);
 		if(acc == NULL) return FALSE;
-		account_balances_add_internal(acc, trn);
+		account_balances_add_internal(acc, txn);
 		return TRUE;
 	}
 	return FALSE;
