@@ -1,5 +1,5 @@
 /*	HomeBank -- Free, easy, personal accounting for everyone.
- *	Copyright (C) 1995-2021 Maxime DOYEN
+ *	Copyright (C) 1995-2022 Maxime DOYEN
  *
  *	This file is part of HomeBank.
  *
@@ -245,7 +245,11 @@ gboolean isvalid = FALSE;
 	
 	hb_string_strip_crlf(rawline);
 	sep = hb_csv_get_separator();
-	str_array = hb_csv_row_get(rawline, sep, 8);
+
+	//#1930924 get all csv column to invalidate csv with more than 8 columns
+	str_array = hb_csv_row_get(rawline, sep, -1);
+	//str_array = hb_csv_row_get(rawline, sep, 8);
+	
 	isvalid = hb_csv_row_valid(str_array, 8, csvtype);
 
 	g_strfreev (str_array);
