@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -635,7 +635,8 @@ gint n_result, n_cols;
 									pos = category_report_id(split->kcat, (tmpsrc == REPORT_SRC_CATEGORY) ? FALSE : TRUE);
 									datatable_trend_add(dt, pos, col, trn_amount, TRUE);
 									//add to parent as well
-									if( tmpsrc == REPORT_SRC_SUBCATEGORY )
+									//#1955046 treeview with child was a test faulty released
+									/*if( tmpsrc == REPORT_SRC_SUBCATEGORY )
 									{
 									//#1859279 test cat as subtype here to avoid count twice
 									Category *cat = da_cat_get(split->kcat);
@@ -645,7 +646,7 @@ gint n_result, n_cols;
 											pos = cat->parent;
 											datatable_trend_add(dt, pos, col, trn_amount, FALSE);
 										}
-									}
+									}*/
 								}
 							}
 						}
@@ -654,7 +655,8 @@ gint n_result, n_cols;
 							pos = category_report_id(ope->kcat, (tmpsrc == REPORT_SRC_CATEGORY) ? FALSE : TRUE);
 							datatable_trend_add(dt, pos, col, trn_amount, TRUE);
 							//add to parent as well
-							if( tmpsrc == REPORT_SRC_SUBCATEGORY )
+							//#1955046 treeview with child was a test faulty released
+							/*if( tmpsrc == REPORT_SRC_SUBCATEGORY )
 							{
 							//#1859279 test cat as subtype here to avoid count twice
 							Category *cat = da_cat_get(ope->kcat);
@@ -664,7 +666,7 @@ gint n_result, n_cols;
 									pos = cat->parent;
 									datatable_trend_add(dt, pos, col, trn_amount, FALSE);
 								}
-							}
+							}*/
 						}
 						break;
 
