@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -27,7 +27,7 @@
 
 #include <errno.h>
 #include <math.h>
-#include <libintl.h>
+#include <libintl.h>	/* gettext */
 #include <locale.h>
 #include <stdlib.h>		/* atoi, atof, atol */
 #include <string.h>		/* memset, memcpy, strcmp, strcpy */
@@ -75,13 +75,13 @@
 
 #define HOMEBANK_MAJOR	5
 #define HOMEBANK_MINOR	5
-#define HOMEBANK_MICRO	2
+#define HOMEBANK_MICRO	4
 
-#define HB_VERSION		"5.5.2"
+#define HB_VERSION		"5.5.4"
 #define HB_VERSION_NUM	(HOMEBANK_MAJOR*10000) + (HOMEBANK_MINOR*100) + HOMEBANK_MICRO
 
 #define FILE_VERSION		1.4
-#define PREF_VERSION		552
+#define PREF_VERSION		554
 
 #if HB_UNSTABLE == FALSE
 	#define	PROGNAME		"HomeBank"
@@ -206,8 +206,10 @@ typedef enum
 #define ICONNAME_LIST_DELETE		"list-remove-symbolic"
 #define ICONNAME_LIST_DELETE_ALL	"list-remove-all-symbolic"
 #define ICONNAME_CHANGES_PREVENT	"changes-prevent-symbolic"
+#define ICONNAME_CHANGES_ALLOW  	"changes-allow-symbolic"
 #define ICONNAME_SYSTEM_SEARCH		"system-search-symbolic"
 
+
 // custom or gnome not found
 #define ICONNAME_HB_BUTTON_MENU		"open-menu-symbolic"
 #define ICONNAME_HB_BUTTON_COLLAPSE	"list-collapse-all-symbolic"
