@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -615,7 +615,7 @@ gchar *color, *text;
 /* = = = = = = = = = = = = = = = = */
 
 
-static void list_txn_to_string_line(GString *node, gchar sep, Transaction *ope, guint32 kcat, gchar *memo, gdouble amount, gboolean incacc)
+static void list_txn_to_string_line(GString *node, gchar sep, Transaction *ope, guint32 kcat, gchar *memo, gdouble amount, gboolean hasstatus, gboolean hasacc)
 {
 Payee *payee;
 Category *category;
@@ -623,7 +623,7 @@ gchar *tags;
 char strbuf[G_ASCII_DTOSTR_BUF_SIZE];
 
 	//account
-	if( incacc )
+	if( hasacc )
 	{
 	Account *acc = da_acc_get(ope->kacc);
 	
@@ -670,9 +670,12 @@ char strbuf[G_ASCII_DTOSTR_BUF_SIZE];
 
 	//#1847907 v 5.3.2 add reconcile as c column like in pdf export
 	//status
-	g_string_append (node, transaction_get_status_string(ope) );
-	g_string_append_c (node, sep );
-
+	if( hasstatus )
+	{
+		g_string_append (node, transaction_get_status_string(ope) );
+		g_string_append_c (node, sep );
+	}
+	
 	//category
 	category = da_cat_get(kcat);
 	g_string_append (node, (category->fullname != NULL) ? category->fullname : "" );
@@ -689,7 +692,7 @@ char strbuf[G_ASCII_DTOSTR_BUF_SIZE];
 }
 
 
-GString *list_txn_to_string(GtkTreeView *treeview, gboolean clipboard, gboolean incsplit, gboolean incacc)
+GString *list_txn_to_string(GtkTreeView *treeview, gboolean isclipboard, gboolean hassplit, gboolean hasstatus, gboolean hasacc)
 {
 struct list_txn_data *data = NULL;
 GtkTreeModel *model;
@@ -704,10 +707,10 @@ gchar sep;
 	
 	node = g_string_new(NULL);
 
-	sep = (clipboard == TRUE) ? '\t' : ';';
+	sep = (isclipboard == TRUE) ? '\t' : ';';
 
 	// header line
-	if( incacc )
+	if( hasacc )
 	{
 		g_string_append (node, "account" );
 		g_string_append_c (node, sep );
@@ -725,8 +728,11 @@ gchar sep;
 	g_string_append (node, "amount" );
 	g_string_append_c (node, sep );
 	//#1847907 v 5.3.2 add reconcile as c column like in pdf export
-	g_string_append (node, "c" );
-	g_string_append_c (node, sep );
+	if( hasstatus )
+	{
+		g_string_append (node, "c" );
+		g_string_append_c (node, sep );
+	}
 	g_string_append (node, "category" );
 	g_string_append_c (node, sep );
 	g_string_append (node, "tags");
@@ -743,19 +749,19 @@ gchar sep;
 			-1);
 
 		//normal export: if we don't want split or the txn has no split
-		if( (incsplit == FALSE) )
+		if( (hassplit == FALSE) )
 		{
 			amount = ope->amount;
 			//for detail display the split part (if any)
 			if( data && (data->list_type == LIST_TXN_TYPE_DETAIL) )
 				amount = samount;
-			list_txn_to_string_line(node, sep, ope, ope->kcat, ope->memo, amount, incacc);
+			list_txn_to_string_line(node, sep, ope, ope->kcat, ope->memo, amount, hasstatus, hasacc);
 		}
 		else
 		{
 			if( (ope->splits == NULL) )
 			{
-				list_txn_to_string_line(node, sep, ope, ope->kcat, ope->memo, ope->amount, incacc);
+				list_txn_to_string_line(node, sep, ope, ope->kcat, ope->memo, ope->amount, hasstatus, hasacc);
 			}
 			else
 			{
@@ -764,7 +770,7 @@ gchar sep;
 				for(i=0;i<nbsplit;i++)
 				{
 				Split *split = da_splits_get(ope->splits, i);
-					list_txn_to_string_line(node, sep, ope, split->kcat, split->memo, split->amount, incacc);
+					list_txn_to_string_line(node, sep, ope, split->kcat, split->memo, split->amount, hasstatus, hasacc);
 				}
 			}
 		}
@@ -1349,7 +1355,8 @@ Transaction *ope;
 
 /*
 ** create our transaction list
-** Status, Date, Info, Payee, Memo, (Amount), Expense, Income, Category
+** 1 line: Status, Date, Info, Payee, Category, Tags, CLR, (Amount), Expense, Income, Balance, Memo, (Account)
+** 
 */
 GtkWidget *create_list_transaction(gint list_type, gboolean *pref_columns)
 {
