@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -390,9 +390,28 @@ gboolean result;
 
 		if(result == GTK_RESPONSE_ACCEPT)
 		{
+		GtkTreeSelection *treeselection;
+		GtkTreeModel *model;
+		GtkTreeIter iter;
+		GtkTreePath *path = NULL;
+
+			//1936806 keep the selection
+			treeselection = gtk_tree_view_get_selection (GTK_TREE_VIEW(data->LV_report));
+			if (gtk_tree_selection_get_selected(treeselection, &model, &iter))
+			{
+				path = gtk_tree_model_get_path(model, &iter);
+			}
+
 			//#1640885
 			GLOBALS->changes_count++;
 			repbalance_compute (data->window, NULL);
+
+			if( path != NULL )
+			{
+				gtk_tree_selection_select_path(treeselection, path);
+				gtk_tree_path_free(path);
+			}
+
 		}
 
 		da_transaction_free (old_txn);
