@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -269,9 +269,28 @@ gboolean result;
 
 		if(result == GTK_RESPONSE_ACCEPT)
 		{
+		GtkTreeSelection *treeselection;
+		GtkTreeModel *model;
+		GtkTreeIter iter;
+		GtkTreePath *path = NULL;
+
+			//1936806 keep the selection
+			treeselection = gtk_tree_view_get_selection (GTK_TREE_VIEW(data->LV_report));
+			if (gtk_tree_selection_get_selected(treeselection, &model, &iter))
+			{
+				path = gtk_tree_model_get_path(model, &iter);
+			}
+
 			//#1640885
 			GLOBALS->changes_count++;
 			repbudget_compute(data->window, NULL);
+
+			if( path != NULL )
+			{
+				gtk_tree_selection_select_path(treeselection, path);
+				gtk_tree_path_free(path);
+			}
+
 		}
 
 		da_transaction_free (old_txn);
@@ -390,7 +409,7 @@ GString *node;
 	data = user_data;
 	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), TRUE, FALSE, FALSE);
+	node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), TRUE, FALSE, TRUE, FALSE);
 
 	clipboard = gtk_clipboard_get_default(gdk_display_get_default());
 	gtk_clipboard_set_text(clipboard, node->str, node->len);
@@ -423,7 +442,7 @@ gint tmpfor;
 		io = g_io_channel_new_file(filename, "w", NULL);
 		if(io != NULL)
 		{
-			node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), FALSE, FALSE, FALSE);
+			node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), FALSE, FALSE, TRUE, FALSE);
 			g_io_channel_write_chars(io, node->str, -1, NULL, NULL);
 
 			g_io_channel_unref (io);
