@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -145,16 +145,43 @@ struct repstats_data *data = user_data;
 }
 
 
+static void repstats_action_viewstack(GtkToolButton *toolbutton, gpointer user_data)
+{
+struct repstats_data *data = user_data;
+
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(data->GR_result), 2);
+	gtk_chart_set_type (GTK_CHART(data->RE_chart2), CHART_TYPE_STACK);
+	data->charttype = CHART_TYPE_STACK;
+	repstats_sensitive(data->window, NULL);
+}
+
+
+static void repstats_action_viewstack100(GtkToolButton *toolbutton, gpointer user_data)
+{
+struct repstats_data *data = user_data;
+
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(data->GR_result), 2);
+	gtk_chart_set_type (GTK_CHART(data->RE_chart2), CHART_TYPE_STACK100);
+	data->charttype = CHART_TYPE_STACK100;
+	repstats_sensitive(data->window, NULL);
+}
+
+
 static void repstats_action_print(GtkToolButton *toolbutton, gpointer user_data)
 {
 struct repstats_data *data = user_data;
-gint tmpsrc;
+gint tmpsrc, tmpmode;
 gchar *name;
 
 	tmpsrc  = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_src));
+	tmpmode  = hbtk_radio_button_get_active(GTK_CONTAINER(data->RA_mode));
+	
 	name = g_strdup_printf("hb-repstat_%s", hbtk_get_label(CYA_REPORT_SRC,tmpsrc));
 
-	gtk_chart_print(GTK_CHART(data->RE_chart), GTK_WINDOW(data->window), PREFS->path_export, name);
+	if( tmpmode == 0 )
+		gtk_chart_print(GTK_CHART(data->RE_chart), GTK_WINDOW(data->window), PREFS->path_export, name);
+	else
+		gtk_chart_print(GTK_CHART(data->RE_chart2), GTK_WINDOW(data->window), PREFS->path_export, name);
 
 	g_free(name);
 }
@@ -333,7 +360,6 @@ gchar *title;
 
 	gtk_chart_show_xval(GTK_CHART(data->RE_chart), xval);
 
-
 	/* update bar chart */
 	if( (tmptype == REPORT_TYPE_TOTAL) && (usrcomp == TRUE) ) //dual exp/inc
 	{
@@ -348,6 +374,10 @@ gchar *title;
 		gtk_chart_set_datas(GTK_CHART(data->RE_chart), model, column, title, NULL);
 	}
 
+	//time chart
+	gtk_chart_set_color_scheme(GTK_CHART(data->RE_chart2), PREFS->report_color_scheme);
+	gtk_chart_show_xval(GTK_CHART(data->RE_chart2), TRUE);
+	chart_data_series(GTK_CHART(data->RE_chart2), GTK_TREE_VIEW(data->LV_report2), data->trendrows, data->trendcols);
 
 	g_free(title);
 	
@@ -509,7 +539,7 @@ GString *node;
 	data = user_data;
 	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), TRUE, FALSE, FALSE);
+	node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), TRUE, FALSE, TRUE, FALSE);
 
 	clipboard = gtk_clipboard_get_default(gdk_display_get_default());
 	gtk_clipboard_set_text(clipboard, node->str, node->len);
@@ -543,7 +573,7 @@ gint tmpsrc;
 		io = g_io_channel_new_file(filename, "w", NULL);
 		if(io != NULL)
 		{
-			node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), FALSE, FALSE, FALSE);
+			node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), FALSE, FALSE, TRUE, FALSE);
 			g_io_channel_write_chars(io, node->str, -1, NULL, NULL);
 
 			g_io_channel_unref (io);
@@ -743,7 +773,7 @@ GtkTreeIter  iter;
 			if( tmpsrc == REPORT_SRC_ACCOUNT && i == 0 )
 				continue;
 
-			DB( g_printf(" insert %2d, '%s', %9.2f %9.2f %9.2f\n", i, dr->label, dr->expense[0], dr->income[1], dr->expense[0] + dr->income[1]) );
+			DB( g_printf(" insert %2d, '%s', %9.2f %9.2f %9.2f\n", i, dr->label, dr->expense[0], dr->income[1], -dr->expense[0] + dr->income[1]) );
 
 			n_inserted++;
 			totexp += dr->expense[0];
@@ -756,9 +786,10 @@ GtkTreeIter  iter;
 				LST_REPDIST_INCOME , dr->income[1],
 				LST_REPDIST_TOTAL  , dr->expense[0] + dr->income[1],
 				//#1925976 abs is used into hb_rate, no need to - expense
-				LST_REPDIST_EXPRATE, hb_rate(dr->expense[0], data->total_expense),
+				//#1942494 but when sum exp+inc, exp must be abs !
+				LST_REPDIST_EXPRATE, hb_rate(-dr->expense[0], -data->total_expense),
 				LST_REPDIST_INCRATE, hb_rate(dr->income[1] , data->total_income),
-				LST_REPDIST_TOTRATE, hb_rate(dr->expense[0] + dr->income[1], data->total_expense + data->total_income),
+				LST_REPDIST_TOTRATE, hb_rate(-dr->expense[0] + dr->income[1], -data->total_expense + data->total_income),
 				-1);
 		}
 
@@ -788,13 +819,13 @@ GtkTreeIter  iter;
 			LST_REPDIST_EXPENSE, totexp,
 			LST_REPDIST_INCOME , totinc,
 			LST_REPDIST_TOTAL, totexp + totinc,
+			//#1942494 added for 5.5.4
+			LST_REPDIST_EXPRATE, hb_rate(-totexp, -data->total_expense),
+			LST_REPDIST_INCRATE, hb_rate(totinc , data->total_income),
+			LST_REPDIST_TOTRATE, hb_rate(-totexp + totinc, -data->total_expense + data->total_income),
 			-1);
 	}
 
-	repstats_update(widget, user_data);
-
-	
-	
 	
 	/* trend with test mutlti to remove */
 	//TODO: add if mode==1 && choose a better max column value
@@ -834,78 +865,29 @@ GtkTreeIter  iter;
 		GtkTreeViewColumn *column = gtk_tree_view_get_column( GTK_TREE_VIEW(data->LV_report2), 0);
 		gtk_tree_view_column_set_title(column, hbtk_get_label(CYA_REPORT_SRC,tmpsrc));
 
-		if( tmpsrc == REPORT_SRC_SUBCATEGORY )
+		//#1955046 treeview with child was a test faulty released
+		for(i=0; i<n_result; i++)
 		{
-		GList *l, *clist = category_glist_sorted(1);
+		DataRow *dr = dt->rows[i];
+		gdouble total = da_datarow_get_cell_sum(dr, dt->nbcols+1);
 
-			l = g_list_first(clist);
-			while(l !=  NULL)
-			{
-			Category *cat = l->data;
+			DB( g_printf(" eval item %4d:'%s' %.2f\n", i, dr->label, total ) );
 
-				if(cat)
-				{
-				DataRow *dr = dt->rows[cat->key];
-				gdouble total = da_datarow_get_cell_sum(dr, dt->nbcols+1);
+			if( !total )
+				continue;
 
-					DB( g_printf(" eval cat %4d:'%s' = '%s' %.2f\n", cat->key, cat->name, dr->label, total) );
-					
-					if( total )
-					{
-						if( cat->parent == 0 )
-						{
-							DB( g_printf(" > insert\n") );
-							n_inserted++;
-							gtk_tree_store_insert_with_values(GTK_TREE_STORE(model), &iter, NULL, -1,
-								LST_REPDIST2_KEY, cat->key,
-								LST_REPDIST2_LABEL, dr->label,
-								LST_REPDIST2_ROW, dr,
-								-1);
-						}
-						else
-						{
-						GtkTreeIter  iter2;
-
-							DB( g_printf(" > insert\n") );
-							n_inserted++;
-							gtk_tree_store_insert_with_values(GTK_TREE_STORE(model), &iter2, &iter, -1,
-								LST_REPDIST2_KEY, cat->key,
-								LST_REPDIST2_LABEL, dr->label,
-								LST_REPDIST2_ROW, dr,
-								-1);
-						}
-					}
-					else
-					{
-						DB( g_printf(" > skipped\n") );
-					}
-				}
-				l = g_list_next(l);
-			}
-			g_list_free(clist);
-		}	
-		else
-		{
-			for(i=0; i<n_result; i++)
-			{
-			DataRow *dr = dt->rows[i];
-			gdouble total = da_datarow_get_cell_sum(dr, dt->nbcols+1);
-
-				DB( g_printf(" eval item %4d:'%s' %.2f\n", i, dr->label, total ) );
-
-				if( !total )
-					continue;
-
-				DB( g_printf(" --> insert\n") );
-				n_inserted++;
-				gtk_tree_store_insert_with_values(GTK_TREE_STORE(model), &iter, NULL, -1,
-					LST_REPDIST2_KEY, i,
-					LST_REPDIST2_LABEL, dr->label,
-					LST_REPDIST2_ROW, dr,
-					-1);
-			}
+			DB( g_printf(" --> insert\n") );
+			n_inserted++;
+			gtk_tree_store_insert_with_values(GTK_TREE_STORE(model), &iter, NULL, -1,
+				LST_REPDIST2_KEY, i,
+				LST_REPDIST2_LABEL, dr->label,
+				LST_REPDIST2_ROW, dr,
+				-1);
 		}
 
+		data->trendrows = n_inserted;
+		data->trendcols = n_cols;
+
 		//insert total
 		if( n_inserted > 1 )
 		{
@@ -936,6 +918,10 @@ GtkTreeIter  iter;
 		//liststore_benchmark();
 
 		/* test multi end */
+
+		repstats_update(widget, user_data);
+
+
 	}
 		
 }
@@ -966,12 +952,16 @@ gint mode, type, page;
 	hb_widget_visible(data->CM_compare, visible);
 	hb_widget_visible(data->BT_column, visible);
 	hb_widget_visible(data->BT_donut, visible);
+	hb_widget_visible(data->BT_stack, !visible);
+	hb_widget_visible(data->BT_stack100, !visible);
 	hb_widget_visible(data->BT_rate, visible);
 	hb_widget_visible(data->LB_intvl, !visible);
 	hb_widget_visible(data->CY_intvl, !visible);
 
 	//zoom
-	visible = (data->charttype == CHART_TYPE_COL) ? TRUE : FALSE;
+	visible = (data->charttype == CHART_TYPE_COL 
+			|| data->charttype == CHART_TYPE_STACK 
+			|| data->charttype == CHART_TYPE_STACK100) ? TRUE : FALSE;
 	hb_widget_visible(data->LB_zoomx, visible);
 	hb_widget_visible(data->RG_zoomx, visible);
 
@@ -983,7 +973,8 @@ gint mode, type, page;
 	hb_widget_visible (data->BT_detail, visible);
 	hb_widget_visible (data->BT_export, visible);
 
-	visible = (mode==0 && page > 0) ? TRUE : FALSE;
+	//visible = (mode==0 && page > 0) ? TRUE : FALSE;
+	visible = (page > 0) ? TRUE : FALSE;
 	hb_widget_visible (data->BT_legend, visible);
 	hb_widget_visible (data->BT_print, visible);
 	
@@ -1018,9 +1009,29 @@ gboolean result;
 
 		if(result == GTK_RESPONSE_ACCEPT)
 		{
+		GtkTreeSelection *treeselection;
+		GtkTreeModel *model;
+		GtkTreeIter iter;
+		GtkTreePath *path = NULL;
+
+			//1936806 keep the selection
+			gint tmpmode  = hbtk_radio_button_get_active(GTK_CONTAINER(data->RA_mode));
+			
+			treeselection = gtk_tree_view_get_selection (GTK_TREE_VIEW(tmpmode == 0 ? data->LV_report : data->LV_report2));
+			if (gtk_tree_selection_get_selected(treeselection, &model, &iter))
+			{
+				path = gtk_tree_model_get_path(model, &iter);
+			}
+
 			//#1640885
 			GLOBALS->changes_count++;
 			repstats_compute(data->window, NULL);
+
+			if( path != NULL )
+			{
+				gtk_tree_selection_select_path(treeselection, path);
+				gtk_tree_path_free(path);
+			}
 		}
 
 		da_transaction_free (old_txn);
@@ -1087,7 +1098,6 @@ struct repstats_data *data;
 static void repstats_toggle_legend(GtkWidget *widget, gpointer user_data)
 {
 struct repstats_data *data;
-//gint active;
 
 	DB( g_print("\n[repdist] toggle legend\n") );
 
@@ -1097,6 +1107,8 @@ struct repstats_data *data;
 
 	gtk_chart_show_legend(GTK_CHART(data->RE_chart), data->legend, FALSE);
 	gtk_chart_queue_redraw(GTK_CHART(data->RE_chart));
+	gtk_chart_show_legend(GTK_CHART(data->RE_chart2), data->legend, FALSE);
+	gtk_chart_queue_redraw(GTK_CHART(data->RE_chart2));
 }
 
 static void repstats_zoomx_callback(GtkWidget *widget, gpointer user_data)
@@ -1113,6 +1125,7 @@ gdouble value;
 	DB( g_print(" + scale is %.2f\n", value) );
 
 	gtk_chart_set_barw(GTK_CHART(data->RE_chart), value);
+	gtk_chart_set_barw(GTK_CHART(data->RE_chart2), value);
 
 }
 
@@ -1160,8 +1173,11 @@ struct repstats_data *data;
 
 	//hbfile_update(data->LV_acc, (gpointer)4);
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_report));
+
 	gtk_chart_show_minor(GTK_CHART(data->RE_chart), GLOBALS->minor);
 	gtk_chart_queue_redraw(GTK_CHART(data->RE_chart));
+	gtk_chart_show_minor(GTK_CHART(data->RE_chart2), GLOBALS->minor);
+	gtk_chart_queue_redraw(GTK_CHART(data->RE_chart2));
 }
 
 
@@ -1229,7 +1245,19 @@ GtkWidget *toolbar, *button;
 	g_object_set (button, "icon-name", ICONNAME_HB_VIEW_DONUT, "label", _("Donut"), NULL);
 	gtk_widget_set_tooltip_text(button, _("View results as donut"));
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(button), -1);
-	
+
+	button = (GtkWidget *)gtk_radio_tool_button_new_from_widget(GTK_RADIO_TOOL_BUTTON(button));
+	data->BT_stack = button;
+	g_object_set (button, "icon-name", ICONNAME_HB_VIEW_STACK, "label", _("Stack"), NULL);
+	gtk_widget_set_tooltip_text(button, _("View results as stack"));
+	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(button), -1);
+
+	button = (GtkWidget *)gtk_radio_tool_button_new_from_widget(GTK_RADIO_TOOL_BUTTON(button));
+	data->BT_stack100 = button;
+	g_object_set (button, "icon-name", ICONNAME_HB_VIEW_STACK100, "label", _("Stack 100%"), NULL);
+	gtk_widget_set_tooltip_text(button, _("View results as stack 100%"));
+	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(button), -1);
+
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), gtk_separator_tool_item_new(), -1);
 
 	button = gtk_widget_new(GTK_TYPE_TOGGLE_TOOL_BUTTON,
@@ -1345,6 +1373,7 @@ static void repstats_window_setup(struct repstats_data *data)
 	repstats_toggle_rate(data->window, NULL);
 	
 	gtk_chart_set_smallfont (GTK_CHART(data->RE_chart), PREFS->rep_smallfont);
+	gtk_chart_set_smallfont (GTK_CHART(data->RE_chart2), PREFS->rep_smallfont);
 
 }
 
@@ -1636,7 +1665,13 @@ gint row;
 	gtk_chart_set_currency(GTK_CHART(widget), GLOBALS->kcur);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), widget, NULL);
 
-	
+	//page: 2d stack/stack100
+	widget = gtk_chart_new(CHART_TYPE_NONE);
+	data->RE_chart2 = widget;
+	gtk_chart_set_minor_prefs(GTK_CHART(widget), PREFS->euro_value, PREFS->minor_cur.symbol);
+	gtk_chart_set_currency(GTK_CHART(widget), GLOBALS->kcur);
+	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), widget, NULL);
+
 	//todo: setup should move this
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_minor), GLOBALS->minor);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_byamount), PREFS->stat_byamount);
@@ -1675,6 +1710,8 @@ gint row;
 	g_signal_connect (G_OBJECT (data->BT_list), "clicked", G_CALLBACK (repstats_action_viewlist), (gpointer)data);
 	g_signal_connect (G_OBJECT (data->BT_column), "clicked", G_CALLBACK (repstats_action_viewbar), (gpointer)data);
 	g_signal_connect (G_OBJECT (data->BT_donut), "clicked", G_CALLBACK (repstats_action_viewpie), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_stack), "clicked", G_CALLBACK (repstats_action_viewstack), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_stack100), "clicked", G_CALLBACK (repstats_action_viewstack100), (gpointer)data);
 	g_signal_connect (G_OBJECT (data->BT_detail), "clicked", G_CALLBACK (repstats_toggle_detail), (gpointer)data);
 	g_signal_connect (G_OBJECT (data->BT_legend), "clicked", G_CALLBACK (repstats_toggle_legend), (gpointer)data);
 	g_signal_connect (G_OBJECT (data->BT_rate), "clicked", G_CALLBACK (repstats_toggle_rate), (gpointer)data);
