@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -33,6 +33,8 @@ enum {
 struct repstats_data
 {
 	DataTable	*trend;
+	gint		trendrows;
+	gint		trendcols;
 
 	GQueue		*txn_queue;
 	Filter		*filter;
@@ -53,6 +55,8 @@ struct repstats_data
 	GtkWidget	*BT_list;
 	GtkWidget	*BT_column;
 	GtkWidget	*BT_donut;
+	GtkWidget	*BT_stack;
+	GtkWidget	*BT_stack100;
 	GtkWidget	*BT_detail;
 	GtkWidget	*BT_legend;
 	GtkWidget	*BT_rate;
@@ -88,6 +92,7 @@ struct repstats_data
 	GtkWidget	*TX_total[3];
 
 	GtkWidget	*RE_chart;
+	GtkWidget	*RE_chart2;
 
 	GtkWidget	*GR_detail;
 	GtkWidget	*LV_detail;
