@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -181,8 +181,9 @@ gchar *outstr, *name;
 			while (valid)
 			{
 			guint32 julian;
-			gint meter, dist, distbyvol;
-			gdouble fuel, price, amount, centkm;
+			gint meter, dist;
+			//#1947931 distbyvol in double not int
+			gdouble fuel, price, amount, centkm, distbyvol; 
 			gboolean partial;
 			gchar datebuf[16];
 
@@ -200,7 +201,7 @@ gchar *outstr, *name;
 				
 				hb_sprint_date(datebuf, julian);
 
-				outstr = g_strdup_printf("%s;%d;%.2f;%.2f;%.2f;%d;%.2f;%d;%d\n", 
+				outstr = g_strdup_printf("%s;%d;%.2f;%.2f;%.2f;%d;%.2f;%.2f;%d\n", 
 					datebuf, meter, fuel, price, amount, dist, centkm, distbyvol, partial);
 				g_io_channel_write_chars(io, outstr, -1, NULL, NULL);
 
