@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -132,7 +132,19 @@ gint retval = 0;
 			tmpval = item1->amount - item2->amount;
 			retval = tmpval > 0 ? 1 : -1;
 			break;
+		//#1928147 sort on account as well
+		case LST_DEFARC_SORT_ACCOUNT:
+			{
+			Account *a1, *a2;
 
+				a1 = da_acc_get(item1->kacc);
+				a2 = da_acc_get(item2->kacc);
+				if( a1 != NULL && a2 != NULL )
+				{
+					retval = hb_string_utf8_compare(a1->name, a2->name);
+				}
+			}
+			break;
 			
 		default:
 			g_return_val_if_reached(0);
@@ -515,7 +527,7 @@ gboolean selected, sensitive;
 
 
 static void
-ui_arc_manage_cd_schedule_changed(GtkWidget *widget, gpointer user_data)
+ui_arc_manage_cb_schedule_changed(GtkWidget *widget, gpointer user_data)
 {
 struct ui_arc_manage_data *data;
 Archive *arcitem;
@@ -747,8 +759,9 @@ gint result;
 		
 		gtk_tree_model_get(model, &iter, LST_DEFARC_DATAS, &item, -1);
 
+		//#1940103 as memo can be null, use (no memo) instead
 		title = g_strdup_printf (
-			_("Are you sure you want to permanently delete '%s'?"), item->memo);
+			_("Are you sure you want to permanently delete '%s'?"), item->memo != NULL ? item->memo : _("(no memo)") );
 
 		secondtext = _("If you delete a scheduled/template, it will be permanently lost.");
 		
@@ -1203,8 +1216,8 @@ gint w, h, dw, dh;
 
 	g_signal_connect (popover, "closed", G_CALLBACK (ui_arc_manage_cb_popover_closed), NULL);
 	
-	g_signal_connect (data->CM_auto,  "notify::active", G_CALLBACK (ui_arc_manage_cd_schedule_changed), NULL);
-	g_signal_connect (data->CM_limit, "toggled", G_CALLBACK (ui_arc_manage_cd_schedule_changed), NULL);
+	g_signal_connect (data->CM_auto,  "notify::active", G_CALLBACK (ui_arc_manage_cb_schedule_changed), NULL);
+	g_signal_connect (data->CM_limit, "toggled", G_CALLBACK (ui_arc_manage_cb_schedule_changed), NULL);
 	
 	//setup, init and show dialog
 	ui_arc_manage_setup(data);
