@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -822,9 +822,14 @@ Account *acc;
 					manage break intxfer
 
 			* always manage account change
-
 		*/
 
+		//#1931816: sort if date changed
+		if(old_txn->date != new_txn->date)
+		{
+			da_transaction_queue_sort(acc->txn_queue);		
+		}
+
 		//if( new_txn->paymode == PAYMODE_INTXFER )
 		if( new_txn->flags & OF_INTXFER )
 		{
