@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -927,6 +927,71 @@ guint i;
 	return box;
 }
 
+
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
+
+#ifdef G_OS_WIN32
+
+static GtkWidget *hbtk_container_get_children_named(GtkContainer *container, gchar *buildname)
+{
+GList *lchild, *list;
+GtkWidget *widget = NULL;
+gint i;
+
+	if(!GTK_IS_CONTAINER(container))
+		return NULL;
+	
+	lchild = list = gtk_container_get_children (container);
+	for(i=0;list != NULL;i++)
+	{
+		if( hb_string_ascii_compare(buildname, (gchar *)gtk_buildable_get_name(list->data)) == 0 )
+		{
+			widget = list->data;
+			break;
+		}
+		list = g_list_next(list);
+	}
+	g_list_free(lchild);
+
+	return widget;
+}
+
+
+void hbtk_assistant_hack_button_order(GtkAssistant *assistant)
+{
+GtkWidget *bmain, *bchild, *barea, *bbutton;
+
+	//main_box
+	bmain = gtk_bin_get_child(GTK_BIN(assistant));
+	if( !bmain ) return;
+	DB( g_print(" got %s\n", gtk_buildable_get_name(bmain)) );
+	
+	bchild = hbtk_container_get_children_named(GTK_CONTAINER(bmain), "content_box");
+	if( !bchild ) return;
+	DB( g_print(" got %s\n", gtk_buildable_get_name(bchild)) );
+
+	barea = hbtk_container_get_children_named(GTK_CONTAINER(bchild), "action_area");
+	if( !barea ) return;
+	DB( g_print(" got %s\n", gtk_buildable_get_name(barea)) );
+
+	//assistant buttonbox is GTK_PACK_END
+	bbutton = hbtk_container_get_children_named(GTK_CONTAINER(barea), "back");
+	if(bbutton) gtk_box_reorder_child(GTK_BOX(barea), bbutton, 5);
+	bbutton = hbtk_container_get_children_named(GTK_CONTAINER(barea), "forward");
+	if(bbutton) gtk_box_reorder_child(GTK_BOX(barea), bbutton, 4);
+	bbutton = hbtk_container_get_children_named(GTK_CONTAINER(barea), "apply");
+	if(bbutton) gtk_box_reorder_child(GTK_BOX(barea), bbutton, 3);
+	bbutton = hbtk_container_get_children_named(GTK_CONTAINER(barea), "last");
+	if(bbutton) gtk_box_reorder_child(GTK_BOX(barea), bbutton, 2);
+	bbutton = hbtk_container_get_children_named(GTK_CONTAINER(barea), "cancel");
+	if(bbutton) gtk_box_reorder_child(GTK_BOX(barea), bbutton, 1);
+	bbutton = hbtk_container_get_children_named(GTK_CONTAINER(barea), "close");
+	if(bbutton) gtk_box_reorder_child(GTK_BOX(barea), bbutton, 0);
+}
+
+#endif
+
+
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
